'use strict';

/* eslint no-console: 0 */
const address = require('address');
const qrcode = require('qrcode-terminal');
const webpack = require('webpack');
const paths = require('./paths');
const webpackConfigBase = require('./webpack.config.base');
const options = require('../utils/parse-options');
const RaxHotModuleReplacementPlugin = require('rax-hot-module-replacement-webpack-plugin');

const webpackConfigDev = Object.assign({}, webpackConfigBase);

const devConfig = require(paths.resolveApp('src/config/dev'));
const webpackDevServerConfig = devConfig.webpackDevServer || {};

const newEntryList = {};
const webpackLocalSubcontractConfig = devConfig.fileList && devConfig.fileList[0] || [];

// enable source map
webpackConfigDev.devtool = 'eval-source-map';
// Module hot accept
webpackConfigDev.module.loaders.forEach(loader => {
  if (loader.test.toString() === /\.jsx?$/.toString()) {
    loader.loaders.push(`${require.resolve('../loaders/module-hot-accept')}?appIndex=${paths.appIndexJs}`);
  }
});

Object.keys(webpackConfigDev.entry).forEach(point => {
  if (webpackDevServerConfig.hotReload === false) {
    return;
  }
  // Enable hot reloading
  webpackConfigDev.entry[point].unshift(require.resolve('rax-hot-loader/patch'));
  // webpackConfigDev.entry[point].unshift(`${require.resolve('webpack-dev-server/client')}?${options.protocol}//${options.host}:${options.port}`);
  // // bundle the client for webpack-dev-server
  // // and connect to the provided endpoint
  // webpackConfigDev.entry[point].unshift(require.resolve('webpack/hot/only-dev-server'));
  // // bundle the client for hot reloading
  // // only- means to only hot reload for successful updates

  // hot reaload client.
  webpackConfigDev.entry[point].unshift(require.resolve('../dev-utils/webpackHotDevClient'));
  webpackLocalSubcontractConfig.forEach(item => {
    if (point.indexOf(item) > -1) {
      newEntryList[point] = webpackConfigDev.entry[point];
    }
  })
});

if (webpackLocalSubcontractConfig.length > 0) webpackConfigDev.entry = newEntryList;

// Only work on web
webpackConfigDev.plugins.push(new RaxHotModuleReplacementPlugin());
webpackConfigDev.plugins.push(new webpack.NoEmitOnErrorsPlugin());

module.exports = webpackConfigDev;
